==> brobygger-li-2.3.2.tar.gz: brobygger-li-2.3.2/scraper/linkedin/companies/items.py <==
"""
Title     : Company items
Objective :
Created by: Abdellah Janid
Created on: 6/15/20
"""
# Standard library imports

# Related third party imports
from bs4 import BeautifulSoup

# Import local applications
from scraper import scraping_tools as mt


def get_top_card(soup: BeautifulSoup):
    """
    Get top card info
    Returns
    -------
    info : dict
        a list of dictionaries with the following {keys: values}
        name       : str
            name of the organization
        industry      : str, default None
            Industry
        location        : str, default None
            location in about section.
        followers        : str, default None
            followers of the company on linkedin.
        employees_on_li     : str, default None
            Employees list link.
        connections_in_org     : str, default None
            Personal connections in the organization

    """
    info = mt.get_info(soup, {
        'name': 'h1.org-top-card-summary__title',
        'industry': 'div.org-top-card-summary-info-list__info-item',
        'tagline': 'p.org-top-card-summary__tagline',
        'location': 'div.inline-block div.org-top-card-summary-info-list__info-item',
        'followers': 'div.inline-block div:nth-of-type(2)',
        'employees_on_li': 'div .org-top-card-secondary-content__see-all',
        'connections_in_org': '.org-top-card-secondary-content__connections span',
    })
    try:
        if info['followers']:
            info['followers'] = int(info['followers'].split("\n")[-1].replace("followers", "").replace(",", "").strip())

        if info['employees_on_li']:
            info['employees_on_li'] = int(
                info['employees_on_li'].replace("employees", "").replace("employee", "").replace(",", "").strip())
    except:
        pass

    info['website'] = mt.get_attribute_value(soup,
                                             'a.org-top-card-primary-actions__action',
                                             "href")

    info['url_connections_in_org'] = None
    if soup.select_one(".org-top-card-secondary-content__connections"):
        info['url_connections_in_org'] = mt.get_attribute_value(soup,
                                                                '.org-top-card-secondary-content__connections a',
                                                                "href")
        info['url_employees'] = mt.get_attribute_value(soup,
                                                       '.org-top-card-secondary-content__connections a:nth-of-type(2)',
                                                       "href")
    else:
        info['url_employees'] = mt.get_attribute_value(soup,
                                                       'div.mt2.mb1 a',
                                                       "href")

    if info['url_connections_in_org'] is not None:
        info['url_connections_in_org'] = "https://www.linkedin.com" + info['url_connections_in_org']
        info['url_connections_in_org'] = info['url_connections_in_org'].split("&origin=")[0]

    if info['url_employees'] is not None:
        info['url_employees'] = "https://www.linkedin.com" + info['url_employees']
        info['url_employees'] = info['url_employees'].split("&origin=")[0]

    return info


def get_about(soup: BeautifulSoup):
    """
    Get top card info
    Returns
    -------
    info : dict
        a list of dictionaries with the following {keys: values}
        name       : str
            name of the organization
        industry      : str, default None
            Industry
        location        : str, default None
            location in about section.
        followers        : str, default None
            followers of the company on linkedin.
        employees_on_li     : str, default None
            Employees list link.
        connections_in_org     : str, default None
            Personal connections in the organization

    """

    info = mt.get_info(soup, {
        'overview': 'p.break-words',
        'website': 'div.org-top-card-summary-info-list__info-item',
        'industry': 'div.inline-block div.org-top-card-summary-info-list__info-item',
        'staffCountRange': 'div.inline-block',
        'staffCount': 'div.inline-block',
        'headquarters': 'a[data-control-name="topcard_see_all_employees"] span',
        'founded': '.org-top-card-secondary-content__connections span',
        'specialities': '.org-top-card-secondary-content__connections span',
    })

    return info


def get_similar_companies_info(soup: BeautifulSoup):
    """
    Get similar companies info
    Returns
    -------
    info : dict
        a list of dictionaries with the following {keys: values}
        name       : str
            name of the organization
        industry      : str, default None
            Industry
        location        : str, default None
            location in about section.
        followers        : str, default None
            followers of the company on linkedin.
        employees_on_li     : str, default None
            Employees list link.
        connections_in_org     : str, default None
            Personal connections in the organization

    """

    info = mt.get_info(soup, {
        'name': 'h3.break-words',
        'industry': 'span.t-normal',
    })

    info['url'] = mt.get_attribute_value(soup, 'a', "href")
    if info['url'] is not None:
        info['url'] = "https://www.linkedin.com" + info['url']
    return info

==> brobygger-li-2.5.1.tar.gz: brobygger-li-2.5.1/scraper/linkedin/companies/items.py <==
"""
Title     : Company items
Objective :
Created by: Abdellah Janid
Created on: 6/15/20
"""
# Standard library imports

# Related third party imports
from bs4 import BeautifulSoup

# Import local applications
from scraper import scraping_tools as mt


def get_top_card(soup: BeautifulSoup):
    """
    Get top card info
    Returns
    -------
    info : dict
        a list of dictionaries with the following {keys: values}
        name       : str
            name of the organization
        industry      : str, default None
            Industry
        location        : str, default None
            location in about section.
        followers        : str, default None
            followers of the company on linkedin.
        employees_on_li     : str, default None
            Employees list link.
        connections_in_org     : str, default None
            Personal connections in the organization

    """
    info = mt.get_info(soup, {
        'industry': 'div.org-top-card-summary-info-list__info-item',
        'tagline': 'p.org-top-card-summary__tagline',
        'location': 'div.inline-block div.org-top-card-summary-info-list__info-item',
        'followers': 'div.inline-block div:nth-of-type(2)',
        'employees_on_li': 'div .org-top-card-secondary-content__see-all',
        'connections_in_org': '.org-top-card-secondary-content__connections span',
    })
    try:
        if info['followers']:
            info['followers'] = int(info['followers'].split("\n")[-1].replace("followers", "").replace(",", "").strip())

        if info['employees_on_li']:
            info['employees_on_li'] = int(
                info['employees_on_li'].replace("employees", "").replace("employee", "").replace(",", "").strip())
    except:
        pass
    info['name'] = mt.get_attribute_value(soup,
                                             'h1',
                                             "title")

    info['website'] = mt.get_attribute_value(soup,
                                             'a.org-top-card-primary-actions__action',
                                             "href")

    info['url_connections_in_org'] = None
    if soup.select_one(".org-top-card-secondary-content__connections"):
        info['url_connections_in_org'] = mt.get_attribute_value(soup,
                                                                '.org-top-card-secondary-content__connections a',
                                                                "href")
        info['url_employees'] = mt.get_attribute_value(soup,
                                                       '.org-top-card-secondary-content__connections a:nth-of-type(2)',
                                                       "href")
    else:
        info['url_employees'] = mt.get_attribute_value(soup,
                                                       'div.mt2.mb1 a',
                                                       "href")

    if info['url_connections_in_org'] is not None:
        info['url_connections_in_org'] = "https://www.linkedin.com" + info['url_connections_in_org']
        # info['url_connections_in_org'] = info['url_connections_in_org'].split("&origin=")[0]

    if info['url_employees'] is not None:
        info['url_employees'] = "https://www.linkedin.com" + info['url_employees']
        info['url_employees'] = info['url_employees'].split("&origin=")[0]

    return info


def get_about(soup: BeautifulSoup):
    """
    Get top card info
    Returns
    -------
    info : dict
        a list of dictionaries with the following {keys: values}
        name       : str
            name of the organization
        industry      : str, default None
            Industry
        location        : str, default None
            location in about section.
        followers        : str, default None
            followers of the company on linkedin.
        employees_on_li     : str, default None
            Employees list link.
        connections_in_org     : str, default None
            Personal connections in the organization

    """

    info = mt.get_info(soup, {
        'overview': 'p.break-words',
        'website': 'div.org-top-card-summary-info-list__info-item',
        'industry': 'div.inline-block div.org-top-card-summary-info-list__info-item',
        'staffCountRange': 'div.inline-block',
        'staffCount': 'div.inline-block',
        'headquarters': 'a[data-control-name="topcard_see_all_employees"] span',
        'founded': '.org-top-card-secondary-content__connections span',
        'specialities': '.org-top-card-secondary-content__connections span',
    })

    return info


def get_similar_companies_info(soup: BeautifulSoup):
    """
    Get similar companies info
    Returns
    -------
    info : dict
        a list of dictionaries with the following {keys: values}
        name       : str
            name of the organization
        industry      : str, default None
            Industry
        location        : str, default None
            location in about section.
        followers        : str, default None
            followers of the company on linkedin.
    """

    info = mt.get_info(soup, {
        'name': '.artdeco-entity-lockup__title',
        'industry': '.artdeco-entity-lockup__subtitle',
        'followers': '.artdeco-entity-lockup__caption'
    })

    info['url'] = mt.get_attribute_value(soup, 'a', "href")
    if info['url'] is not None:
        info['url'] = mt.validate_link(info['url'])
    return info
